FIPSCode

Struct FIPSCode 

pub struct FIPSCode(/* private fields */);
Encodes a hierarchical FIPS geographic region code in 64 bits. Excludes the nonhierarchical codes places, congressional or state legislative districts, and ZIP code tabulation areas. (See the module level documentation.)

Implementations

Source

impl FIPSCode

pub fn with_state(state: USState) -> Self

Constructs a new FIPSCode from a USState. Unlike the other constructors, this constructor is infallible.

pub fn with_state_code(state_code: StateCode) -> Result<Self, FIPSError>

Constructs a new FIPSCode. Returns Err(()) if the data provided is out of range.

pub fn with_county( state: StateCode, county: CountyCode, ) -> Result<Self, FIPSError>

Constructs a new FIPSCode. Returns Err(()) if the data provided is out of range.

pub fn with_tract( state: StateCode, county: CountyCode, tract: TractCode, ) -> Result<Self, FIPSError>

Constructs a new FIPSCode. Returns Err(()) if the data provided is out of range.

pub fn with_category( state: StateCode, county: CountyCode, tract: TractCode, category: SettingCategoryCode, ) -> Result<Self, FIPSError>

Constructs a new FIPSCode. Returns Err(()) if the data provided is out of range.

pub fn new( state: StateCode, county: CountyCode, tract: TractCode, category: SettingCategoryCode, id: IdCode, data: DataCode, ) -> Result<Self, FIPSError>

pub fn state(&self) -> Result<USState, FIPSError>

Returns the FIPS STATE as a USState enum variant. Returns Err(()) if USState cannot represent the state code. Use FIPSCode::state_code() to retrieve the state code in this case.

pub fn state_code(&self) -> StateCode

Returns the FIPS STATE code as a StateCode (a u8)

pub fn county_code(&self) -> CountyCode

Returns the numeric FIPS COUNTY code

pub fn census_tract_code(&self) -> TractCode

Returns the numeric FIPS CENSUS TRACT code

pub fn category_code(&self) -> SettingCategoryCode

Returns the numeric SETTING CATEGORY code

pub fn id(&self) -> IdCode

Returns the monotonically increasing ID number as an IdCode

pub fn data(&self) -> DataCode

Returns the unused data region occupying the 9 LSB

pub fn set_state(&self, state: USState) -> Self

Creates a copy of self with the FIPS STATE set to state.

pub fn set_state_code(&self, state_code: StateCode) -> Result<Self, FIPSError>

Creates a copy of self with the FIPS STATE set to state.

pub fn set_county(&self, county: CountyCode) -> Result<Self, FIPSError>

Creates a copy of self with the FIPS COUNTY set to county.

pub fn set_tract(&self, tract: TractCode) -> Result<Self, FIPSError>

Creates a copy of self with the FIPS CENSUS TRACT set to tract.

pub fn set_category( &self, category: SettingCategoryCode, ) -> Result<Self, FIPSError>

Creates a copy of self with the setting category set to category.

pub fn set_id(&self, id: IdCode) -> Result<Self, FIPSError>

Creates a copy of self with the ID number set to id.

pub fn set_data(&self, data: DataCode) -> Result<Self, FIPSError>

Creates a copy of self with the unused data region set to data.

pub fn set_data_in_place(&mut self, data: DataCode) -> Result<(), FIPSError>

Sets the unused data region occupying the 10 LSB in place. Returns Ok(()) if data is in range, Err(FIPSError) otherwise.

pub fn compare_non_data(&self, other: Self) -> Ordering

Compares the given values without respect to the data region (the Least Significant Bits). Use the usual equality operators for comparing FIPSCodes including the data region.