pub fn parse_county_code(input: &str) -> FIPSParseResult<'_, u16>Expand description
Parses the first three digits of input as a FIPS county code.
pub fn parse_county_code(input: &str) -> FIPSParseResult<'_, u16>Parses the first three digits of input as a FIPS county code.