pub fn parse_state_code(input: &str) -> FIPSParseResult<'_, StateCode>Expand description
Parses the first two decimal digits of input into a StateCode.
pub fn parse_state_code(input: &str) -> FIPSParseResult<'_, StateCode>Parses the first two decimal digits of input into a StateCode.