pub fn parse_tract_code(input: &str) -> FIPSParseResult<'_, u32>Expand description
Parses the first six digits of input as a FIPS census tract code.
pub fn parse_tract_code(input: &str) -> FIPSParseResult<'_, u32>Parses the first six digits of input as a FIPS census tract code.