FIPSError

Struct FIPSError 

pub struct FIPSError { /* private fields */ }

Implementations

Source

impl FIPSError

pub fn new(parameter_name: &'static str, value: u64, min: u64, max: u64) -> Self

pub fn from_us_state(value: StateCode) -> Self

This one is unique in that it represents an error converting a (presumably valid) StateCode to a [USState] variant. We lie a little bit and claim that values in 1..57 are valid when 3, 7, 14, 43, and 52 are not.

pub fn from_state_code(value: StateCode) -> Self

pub fn from_county_code(value: CountyCode) -> Self

pub fn from_tract_code(value: TractCode) -> Self

pub fn from_setting_category_code(value: SettingCategoryCode) -> Self

pub fn from_id_code(value: IdCode) -> Self

pub fn from_data_code(value: DataCode) -> Self