pub struct ExpandedFIPSCode {
pub state: StateCode,
pub county: CountyCode,
pub tract: TractCode,
pub category: SettingCategoryCode,
pub id: IdCode,
pub data: DataCode,
}Expand description
A struct that holds an expanded version of a FIPSCode in which all fields are represented by
their associated numeric types.
It is up to the client code to ensure the field values are within range. See the module level docs for range constraints.
This struct is useful for converting raw data to/from a FIPSCode for temporary direct field access.
Fields
state: StateCodecounty: CountyCodetract: TractCodecategory: SettingCategoryCodeid: IdCodedata: DataCodeImplementations
Sourceimpl ExpandedFIPSCode
impl ExpandedFIPSCode
pub fn from_fips_code(fips_code: FIPSCode) -> Self
pub fn to_fips_code(&self) -> Result<FIPSCode, FIPSError>